{ config, libs, pkgs, ... }:

{
  imports = [
  ];

  environment.systemPackages = with pkgs; [
    # network toolbox
    arp-scan
    iperf
    iptraf-ng
    nload
    openvpn
    quagga
    telnet
    tinc

    # Multimedia
    audacity
    beep
    cmus
    easytag
    kde4.digikam

    aspell
    cargo
    chromium
    clawsMail
    cloc
    cowsay
    curlftpfs
    dia
    docker
    espeak
    filezilla
    firefox
    freecad
    freemind
    fritzing
    ghc
    gimp
    git-cola
    gnome3.seahorse
    gnumeric
    gnuplot
    gparted
    gpm
    graphviz
    idea.idea-community
    inkscape
    inotify-tools
    iotop
    jekyll
    josm
    kde5.okular
    kde5.quasselClient
    kicad
    linuxPackages.virtualbox
    linuxPackages.virtualboxGuestAdditions
    lm_sensors
    lshw
    lsof
    lyx
    lz4
    lzop
    mcomix
    meld
    mercurial
    mumble
    mutt
    nfs-utils
    ntfs3g
    ntp
    pandoc
    paprefs
    pass
    pavucontrol
    pdfpc
    pgadmin
    picard
    pidgin
    postfix
    powerline-fonts
    powertop
    pwgen
    python27Packages.docker_compose
    python27Packages.turses
    python27Packages.ansible2
    python27Packages.glances
    qpdfview
    qucs
    rustPlatform.rustc
    sakura
    samba
    slock
    smplayer
    spaceFM
    sqlitebrowser
    sshfsFuse
    stack
    subversion
    taskwarrior
    texLiveFull
    thunderbird
    transmission_gtk
    transmission_remote_gtk
    udevil
    unbound
    unetbootin
    usbutils
    vbindiff
    vifm
    viking
    vim
    vlc
    vorbis-tools
    vsftpd
    whois
    wireshark
    wmname
    yubikey-personalization-gui
    zim
  ];

  nixpkgs.config.packageOverrides = pkgs: {
    clawsMail = pkgs.clawsMail.override { enablePluginFancy = true; };
    mumble = pkgs.mumble.override { pulseSupport = true; };
  };

  # Enable the X11 windowing system.
  services.xserver = {
    enable = true;
    layout = "fr";
    xkbOptions = "eurosign:e";
    displayManager.lightdm.enable = true;
    windowManager.awesome.enable = true;
    startGnuPGAgent = true;
    startOpenSSHAgent = false; # pas compatible avec l'agent GnuPG
    inputClassSections = [''
    Identifier  "Marble Mouse"
    MatchProduct "Logitech USB Trackball"
    MatchIsPointer "on"
    MatchDevicePath "/dev/input/event*"
    Driver "evdev"
    # Physical button #s:     A b D - - - - B C    b = A & D simultaneously;   - = no button
    #Option "ButtonMapping" "1 8 3 4 5 6 7 2 2"   #  For right-hand placement
    #Option "ButtonMapping" "3 8 1 4 5 6 7 2 2"   #  For left-hand placement

    # EmulateWheel refers to emulating a mouse wheel using Marble Mouse trackball.
    Option "EmulateWheel" "true"
    Option "EmulateWheelButton" "8"   # Factory default; use "9" for left-side placement.

    # EmulateWheelInertia specifies how far (in pixels) the pointer must move to
    # generate button press/release events in wheel emulation mode.
    Option "EmulateWheelInertia" "10" # Factory default: 50

    Option "ZAxisMapping" "4 5"
    Option "XAxisMapping" "6 7"       # Disable this for vertical-only scrolling.
    # Emulate3Buttons refers to the act of pressing buttons A and D
    # simultaneously to emulate a middle-click or wheel click.
    Option "Emulate3Buttons" "true"   # Factory default.
    ''];
  };

  hardware.pulseaudio = {
    enable = true;
    support32Bit = true;
  };
  environment.etc."pulse/daemon.conf".text = "flat-volumes = no";
}
